# Copyright 2008, Manuel Bekhor - Brussels, Belgium   http://www.bekhor.be 

# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

# Name:		select_instance.rb 1.1
# Description :   	By right clicking, select all the components in the model that are included in your active selection set.
# Author :		Manuel Bekhor   http://www.bekhor.be - Improved by D. Bur
# Usage :		1. Select one ore more components
#			2. Right Click and pick "Select Instances".
#			Right Click works when 1 or more different component are selected. 
# Date :		18/05/2008
# Type: 		Plugin
# History: 		1.0 (18/05/2008) - first version
#			1.1 (18/05/2008) - D.Bur's improvement - compos_valid_selection
#			2.0 (27/05/2008) - Ryo's request: to include components that were made unique.
#			2.1 (01/06/2008) - modified scan test.

require 'sketchup.rb'

def compos_valid_selection
	s=Sketchup.active_model.selection
	return false if s.empty?
	types=[]
	s.each { |e| types.push(e.typename) }
	types.uniq!
	return false if types.length != 1 # check if there's more than one type of object in order to select only components
	return false if types[0]!= "ComponentInstance" # if the selected object(s) is(are) not a component returns false  
	return true if types[0]== "ComponentInstance" # if the selected object(s) is(are) a component returns true
end

def select_component_instance
	i=0
	compo_name = []
	tt = Sketchup.active_model.selection
	 
	for e in tt
		#if (e.kind_of?(Sketchup::ComponentInstance) ) 
			compo_name[i] = e.definition.name
			i += 1
		#end
	end
	 
	ss = Array.new
	ss = Sketchup.active_model.active_entities
	tt.clear

	for e in ss
		i.times do |type|
			if (e.kind_of?(Sketchup::ComponentInstance) && e.definition.name == compo_name[type] && e.visible?) 
				tt.add(e)
			end
		end
	end
end

def select_component_made_unique
	i=0
	compo_name = []
	tt = Sketchup.active_model.selection
	 
	for e in tt
		if (e.kind_of?(Sketchup::ComponentInstance) )
			ss_name = e.definition.name
			splitted_ss_name = ss_name.split ("\#")
			compo_name[i] = splitted_ss_name.at(0)
			i += 1
		end
	end
	 
	ss = Array.new
	ss = Sketchup.active_model.active_entities
	tt.clear

	for e in ss
		i.times do |type|
		if (e.kind_of?(Sketchup::ComponentInstance) )
		scan_name = e.definition.name
		splitted_scan_name = scan_name.split ("\#") 
		start_name = splitted_scan_name.at(0)
			if (e.kind_of?(Sketchup::ComponentInstance) && start_name == compo_name[type]) 
				tt.add(e)
			end
		end
		end
	end
end

if (not file_loaded?("select_instancev2.rb") )
	UI.add_context_menu_handler do |menu|
		if compos_valid_selection
			menu.add_separator
			menu.add_item("Select Instances") { select_component_instance }
			menu.add_item("Select Families") { select_component_made_unique }
		end
	end
end

file_loaded "select_instancev2.rb"